<?php
/**
 * @package WordPress
 * @subpackage Petro
 * @since Petro 1.0.0
 */
defined('ABSPATH') or die();


if ( ! isset( $content_width ) ) $content_width = 2000;

function petro_startup() {


	if((is_child_theme() && !load_theme_textdomain( 'petro', untrailingslashit(get_stylesheet_directory()) . "/languages/")) || !is_child_theme()){
		load_theme_textdomain('petro',untrailingslashit(get_template_directory())."/languages/");
	}

	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-logo', array(
		'height'      => 50,
		'width'       => 150,
		'flex-height' => true,
		'flex-width' => false,
	) );

	add_theme_support( 'woocommerce' );

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header', apply_filters( 'petro_custom_header_args', array(
		'default-image'      => get_template_directory_uri().'/images/banner-page.jpeg',
		'width'              => 1500,
		'height'             => 900,
		'flex-height'        => true,
		'video'              => false,
		'wp-head-callback'   => 'petro_header_style',
	) ) );


	$blog_id="";
	if ( is_multisite()){
		$blog_id="-site".get_current_blog_id();
	}

	add_theme_support( 'editor-styles' );

	add_editor_style( array( petro_fonts_url(), get_template_directory_uri().'/css/bootstrap.css', get_template_directory_uri().'/css/themestyle.css', get_template_directory_uri().'/css/themestyle-rtl.css', get_template_directory_uri() . '/css/style'.$blog_id.'.css') );

	$color_scheme = get_theme_mod( 'color_scheme', 'default' );


	add_theme_support( 'custom-background', apply_filters( 'petro_custom_background_args', array(
		'default-color'      => $color_scheme,
		'default-attachment' => 'fixed',
	) ) );



	register_nav_menus(array(
		'main_navigation' => esc_html__('Top Navigation', 'petro')
	));
	
	add_action( 'wp_enqueue_scripts', 'petro_enqueue_scripts', 9999);
	add_action( 'wp_enqueue_scripts', 'petro_config_loader',1);
	add_filter( 'theme_mod_header_image', 'petro_header_image',1);
	add_filter( 'themegum_glyphicon_list', 'petro_awesome_icon_lists' );
	add_action('themegum-glyph-icon-loaded','petro_load_petro_glyph');
} 

add_action('after_setup_theme','petro_startup');

require_once( get_template_directory().'/lib/tgm.php');
require_once( get_template_directory().'/lib/themegum_functions.php');
require_once( get_template_directory().'/lib/options.php');
require_once( get_template_directory().'/lib/sidebars.php');
require_once( get_template_directory().'/lib/category_attributes.php');

if(function_exists('is_shop')){
  require_once( get_template_directory().'/lib/woocommerce.php'); 
}


if(function_exists('add_builder_element_option')){
	require_once( get_template_directory().'/lib/nuno_elements.php');
}


function petro_tg_custom_post_metabox_title(){

	return esc_html__('Portfolio Information','petro');
}

function petro_enqueue_scripts(){

	
	if(!is_admin() && !defined('IFRAME_REQUEST')) {

	/* just front loaded */

		wp_enqueue_style( 'petro-stylesheet', get_template_directory_uri() . '/style.css', array(), '', 'all');
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array(), '3.3.5' );	

		$blog_id="";
		if ( is_multisite()){
			$blog_id="-site".get_current_blog_id();
		}

		wp_enqueue_style( "awesomeicon",get_template_directory_uri() . '/fonts/font-awesome/font-awesome.css', array(), '', 'all' );
		petro_load_petro_glyph();
		wp_enqueue_style( "petro-main-style",get_template_directory_uri() . '/css/themestyle.css', array(), '', 'all' );

		wp_enqueue_style( 'petro-main-ie', get_template_directory_uri(). '/css/themestyle_ie9.css', array('petro-main-style'));
        wp_style_add_data( 'petro-main-ie', 'conditional', 'IE' );


		if(is_rtl()){
			wp_enqueue_style( "petro-rtl-style",  get_template_directory_uri() . '/css/themestyle-rtl.css', array(), '', 'all' );
		}

		wp_enqueue_style( 'petro-fonts' , petro_fonts_url());

		if(is_child_theme()){
			wp_enqueue_style( 'petro-child-theme-style',get_stylesheet_directory_uri() . '/style.css', array(), '', 'all' );
		}


		if(!get_option( 'css_folder_writeable',true) || petro_get_config('devmode',false)){

			$custom_css = get_theme_mod( 'custom_css' );

			wp_add_inline_style( 'petro-main-style', $custom_css);

		}else{
			wp_enqueue_style( "petro-site-style",get_template_directory_uri() . '/css/style'.$blog_id.'.css', array(), '', 'all' );
		}

	}


    $suffix       = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'modernizr' , get_template_directory_uri() . '/js/modernizr.custom.js', array(), '1.0', true );
    wp_enqueue_script( 'bootstrap' , get_template_directory_uri() . '/js/bootstrap'.$suffix.'.js', array( 'jquery' ), '3.2.0', true );
    wp_enqueue_script( 'petro-theme-script' , get_template_directory_uri() . '/js/themescript.js', array( 'jquery','bootstrap'), '1.0', true );
    wp_enqueue_script( 'jquery.magnific-popup' , get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array( 'jquery'), '1.0', true );

    if(is_single() || is_page()){
	 	wp_enqueue_script( 'comment-reply' );
    }



	$custom_js=petro_get_config('js-code','');

	if(!empty($custom_js)){
		wp_add_inline_script('petro-theme-script', $custom_js);
	}

}

function petro_fonts_url(){

	$fonts_url = '';
	$font_families = array();

	$bodyFont=petro_get_config('body-font');

	if (isset($bodyFont['font-family']) && isset($bodyFont['google']) && $bodyFont['font-family']!='') {
			if (isset($bodyFont['google']) && $bodyFont['google']) {
				$font_families[]= $bodyFont['font-family'].":300,300italic,400,400italic,700,700italic,800,800italic,900,900italic";
			}	
	}else{

		$font_families[]= 'Open Sans:400,400i, 600,700,800';
	}


	$headingFont=petro_get_config('heading-font');

	if (isset($headingFont['font-family']) && isset($headingFont['google']) && $headingFont['font-family']!='') {
		if (isset($headingFont['google']) && $headingFont['google']) {

			$font_families[]= $headingFont['font-family'].":300,300italic,400,400italic,700,700italic,800,800italic,900,900italic";
		}	
	}


	$menuFont=petro_get_config('menu-font');

	if (isset($menuFont['font-family']) && isset($menuFont['google']) && $menuFont['font-family']!='') {
		if (isset($menuFont['google']) && $menuFont['google']) {

			$font_families[]= $menuFont['font-family'].":300,300italic,400,400italic,700,700italic,800,800italic,900,900italic";
		}	
	}

	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);
	 
	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

	return esc_url_raw( $fonts_url );
}


function petro_load_petro_glyph(){
	wp_enqueue_style( "petro-glyph",get_template_directory_uri() . '/fonts/petro-construction/petro-construction.css', array(), '', 'all' );
}

function petro_slug_font_url($font_family,$subset,$font_weight='300,300italic,400,400italic,700,700italic,800,800italic,900,900italic') {

	$fonts_url = '';
	if ( !empty($font_family )) {
		$font_families = array();
	 
		$font_families[] = $font_family.':'.$font_weight;
		 
		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( $subset ),
		);
		 
		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}
	 
	return esc_url_raw( $fonts_url );
} 


function petro_awesome_icon_lists($icons){


  $construction_icon_path=get_template_directory()."/fonts/petro-construction/";

  if($constructions_icons = petro_get_glyph_lists($construction_icon_path)){
    $icons = is_array($icons) ? array_merge( $icons, $constructions_icons ) : $constructions_icons;
  }

  $awesome_icon_path=get_template_directory()."/fonts/font-awesome/";

  if($awesome_icons = petro_get_glyph_lists($awesome_icon_path)){
    $icons = is_array($icons) ? array_merge( $icons, $awesome_icons ) : $awesome_icons;
  }

  return array_unique($icons);
}


?>