<?php
defined('ABSPATH') or die();
/* 
 * Plugin Name: Petro Theme Core
 * Plugin URI: http://themegum.com/
 * Description: Core module for petro theme by TemeGUM.
 * Version: 1.0.6
 * Author: Atawai
 * Author URI: http://themegum.com
 * Domain Path: /languages/
 * Text Domain: petro_core_module
 */

/**
 * @package WordPress
 * @subpackage Petro
 * @since Petro 2.2.2
 */


load_plugin_textdomain('petro_core_module', false, plugin_dir_path(__FILE__). '/languages/');

require_once( plugin_dir_path(__FILE__).'widgets.php');


if(function_exists('add_builder_element_option')){
  require_once( plugin_dir_path(__FILE__).'/nuno_elements.php');
}

class petro_page_attributes{

  function __construct() {

        if(!function_exists('is_plugin_active')){
          include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        }

        if('petro' == get_template()){
            add_action('init', array($this,'init'));
        }
        else{
            add_action( 'admin_notices', array( $this, 'deactive_notice'), 10 );
            $this->deactive();
        }

  }

  function init(){

        add_action( 'admin_menu' , array( $this, 'register_page_metabox'));
        add_action( 'save_post', array( $this, 'save_page_attributes' ));

  }

  function register_page_metabox() {

    $blog_version = get_bloginfo( 'version' );


    if(version_compare($blog_version, '5.0', '<')){

      remove_meta_box('pageparentdiv', 'page','side');
      add_meta_box('temegumpageparentdiv',  esc_html__('Page Attributes','petro_core_module'), array( $this, 'get_page_attributes_meta_box'), 'page', 'side', 'core');

    } 
    else{
      add_meta_box('temegumpageparentdiv',  esc_html__('Special Attributes','petro_core_module'), array( $this, 'get_custom_attributes_meta_box'), 'page', 'side', 'core');
      add_meta_box('temegumservice',  esc_html__('Thumbnail Ico','petro_core_module'), array( $this, 'get_service_attributes_meta_box'), 'petro_service', 'side', 'core');

    }


  }


function save_page_attributes($post_id){

    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
        return $post_id;

 
    if(!wp_verify_nonce( isset($_POST['petro_attribute_metabox'])?sanitize_text_field($_POST['petro_attribute_metabox']):"", 'petro_attribute_metabox'))
        return;

    if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
    }

    $post_type = get_post_type();

     if('page'== $post_type){

       $old_page_args = (array) get_post_meta( $post_id, '_petro_page_args', true );
       $page_attributes = petro_valid_page_attributes();
       $new_page_args = array();

       if(count($page_attributes)){
          foreach ($page_attributes as $page_attribute) {
            $new_page_args[$page_attribute] = (isset($_POST[$page_attribute]))?sanitize_text_field($_POST[$page_attribute]):'';
          }
       }

       update_post_meta( $post_id, '_petro_page_args', $new_page_args,$old_page_args );
    }elseif('petro_service'== $post_type ){

       $old_page_args = (array) get_post_meta( $post_id, '_petro_service_args', true );
       $page_attributes = array('service_icon');
       $new_page_args = array();

       if(count($page_attributes)){
          foreach ($page_attributes as $page_attribute) {
            $new_page_args[$page_attribute] = (isset($_POST[$page_attribute]))?sanitize_text_field($_POST[$page_attribute]):'';
          }
       }

       update_post_meta( $post_id, '_petro_service_args', $new_page_args,$old_page_args );
    }
}

function get_service_attributes_meta_box($post){


  if ( 'petro_service' != $post->post_type )
      return true;

    global $petro_config;

    wp_nonce_field( 'petro_attribute_metabox','petro_attribute_metabox');




    wp_enqueue_style( "awesomeicon",get_template_directory_uri() . '/fonts/font-awesome/font-awesome.css', array(), '', 'all' );
    wp_enqueue_style( "petro-glyph",get_template_directory_uri() . '/fonts/petro-construction/petro-construction.css', array(), '', 'all' );
    wp_enqueue_script('icon_picker',get_template_directory_uri().'/lib/icon_picker/icon_picker.js',array('jquery'));
    wp_localize_script( 'icon_picker', 'picker_i18nLocale', array(
      'search_icon'=> esc_html__('Search Icon','petro'),
    ) );

    wp_enqueue_style('icon-picker',get_template_directory_uri().'/lib/icon_picker/icon_picker.css','');

    $page_args = get_post_meta( $post->ID, '_petro_service_args', true );
    $service_icon= isset($page_args['service_icon']) ? $page_args['service_icon']: '';

    $icons= petro_glyphicon_list();

    $post_type_object = get_post_type_object( 'petro_service' );
    $post_type_name = $post_type_object->labels->singular_name;

?>
    <p><?php printf( esc_html__( 'Select the ico for %s layout "Icon Animated With Image"', 'petro_core_module' ), $post_type_name); ?></p>
    <span class="icon-preview"><i class="<?php if ($service_icon!==''){ print esc_attr($service_icon); }?>"></i></span>
     <input type="text" id="category_icon" name="service_icon" value="<?php if ($service_icon!==''){ print esc_attr($service_icon); }?>"/>
     <p><a id="add_icon" href="#" class="selection_button"><?php esc_html_e('Change Icon','petro_core_module');?></a></p>
  <div class="clear"></div>
<script type="text/javascript">
        jQuery(document).ready(function($){
            'use strict';
            var options={
                icons:new Array('<?php print @implode("','",$icons);?>'),
                inline: true,
                onUpdate:function(e){
                  var par=this.closest('#temegumservice'),fieldinput=par.find('[name=service_icon]'),
                  preview=par.find('.icon-preview i');
                  fieldinput.val(e);
                  preview.removeClass().addClass(e);
                }
            };

            $("#add_icon").iconPicker(options);
        });
</script>
<?php
}



function get_page_attributes_meta_box($post) {


  global $petro_config;

  wp_nonce_field( 'petro_attribute_metabox','petro_attribute_metabox');

  $post_type_object = get_post_type_object($post->post_type);
  if ( $post_type_object->hierarchical ) {

    $dropdown_args = array(
      'post_type'        => $post->post_type,
      'exclude_tree'     => $post->ID,
      'selected'         => $post->post_parent,
      'name'             => 'parent_id',
      'show_option_none' => esc_html__('(no parent)','petro'),
      'sort_column'      => 'menu_order, post_title',
      'echo'             => true,
    );

    $dropdown_args = apply_filters( 'page_attributes_dropdown_pages_args', $dropdown_args, $post );
?>
<p><strong><?php esc_html_e('Parent','petro') ?></strong></p>
<label class="screen-reader-text" for="parent_id"><?php esc_html_e('Parent','petro') ?></label>
<?php wp_dropdown_pages( $dropdown_args ); 
  } 

  if ( 'page' != $post->post_type )
      return true;


  wp_enqueue_media();

  $template = !empty($post->page_template) ? $post->page_template : false;
  $templates = get_page_templates();
  $sidebar_position_options=array('default'=>esc_html__('Default','petro'),'left'=>esc_html__('Left','petro'),'right'=>esc_html__('Right','petro'),'nosidebar'=>esc_html__('No Sidebar','petro'));

  $page_args = get_post_meta( $post->ID, '_petro_page_args', true );

  $banner_image= isset($page_args['banner_id']) ? absint($page_args['banner_id']): '';
  $image_url=plugin_dir_url(__FILE__)."/placeholder.png";

  if($banner_image){
    $image = wp_get_attachment_image_src( $banner_image, array( 266,266 ));
    if($image)
      $image_url=$image[0];
  }

  $hide_title = isset($page_args['hide_title']) ? absint($page_args['hide_title']): '';
  $hide_title_heading = isset($page_args['hide_title_heading']) ? absint($page_args['hide_title_heading']): '';
  $sidebar_position = isset($page_args['sidebar_position']) ? $page_args['sidebar_position']: '';

  ksort( $templates );
   ?>
<p id="hide_banner_option">
  <input type="checkbox" name="hide_title" id="hide_title" value="1" <?php echo ($hide_title)?'checked="checked"':""?>/> <?php esc_html_e('Disable heading banner','petro') ?>
</p>
<p id="hide_title_option">
  <input type="checkbox" name="hide_title_heading" id="hide_title_heading" value="1" <?php echo ($hide_title_heading)?'checked="checked"':""?>/> <?php esc_html_e('Hide title heading','petro') ?>
</p>
<p><strong><?php esc_html_e('Template','petro') ?></strong></p>
<label class="screen-reader-text" for="page_template"><?php esc_html_e('Page Template','petro'); ?></label><select name="page_template" id="page_template">
<option value='default'><?php esc_html_e('Default Template','petro'); ?></option>
<?php 
$fn = "esc_html__";

if(count($templates)):

foreach (array_keys( $templates ) as $tmpl )
    : if ( $template == $templates[$tmpl] )
      $selected = " selected='selected'";
    else
      $selected = '';
  echo "\n\t<option value='".$templates[$tmpl]."' $selected>".$fn($tmpl,'petro')."</option>";
  endforeach;
  endif;?>
 ?>
</select>
<div id="custommeta">
<p id="sidebar_option">
  <strong><?php esc_html_e('Sidebar Position','petro') ?></strong>&nbsp;
<select name="sidebar_position" id="sidebar_position">
<?php foreach ($sidebar_position_options as $position=>$label) {
  print "<option value='".$position."'".(($sidebar_position == $position)?" selected":"").">".ucwords($label)."</option>";

}?>
</select>
</p>
</div>

<div id="page-banner">
<p>
  <strong><?php esc_html_e('Heading Image','petro') ?></strong>
</p>
   <div id="banner_image"><img class="btn btn-link upload_image_button" src="<?php echo esc_url( $image_url ); ?>" width="200px" height="200px" /></div>
    <div style="line-height: 60px;">
        <input type="hidden" id="banner_image_id" name="banner_id" value="<?php print ($banner_image)? $banner_image:"";?>" />
        <button type="button" class="upload_image_button button"><?php esc_html_e( 'Upload/Change image', 'petro' ); ?></button>
        <button type="button" class="remove_image_button button"><?php esc_html_e( 'Remove image', 'petro' ); ?></button>
    </div>
</div>


<?php 
if(isset( $petro_config['footer-type'] ) && $petro_config['footer-type']=='page'):
$footer_pages  = isset($petro_config['footer-pages']) ? $petro_config['footer-pages'] : array();
$footer_pages = array_map('absint',(array)$footer_pages);

$page_footer= isset($page_args['page_footer']) ? absint($page_args['page_footer']): '';


?>
<div id="page-footer">
<p><strong><?php esc_html_e('Footer Option','petro') ?></strong></p>
<p><?php esc_html_e( 'The option footer must defined in theme option first.','petro'); ?></p>
<select name="page_footer" id="page_footer">
<option value=''><?php esc_html_e('Default Footer','petro'); ?></option>
<?php 

if(count($footer_pages)):

$args = array(
      'post_type'    => 'page',
      'post_status' => 'publish',
      'posts_per_page' => -1,
      'include'=> $footer_pages
);

$pages = get_pages( $args );

if(count($pages)):

foreach ( $pages as $page ) {

  echo "\n\t<option value='".$page->ID."' ".selected($page->ID,$page_footer).">".$page->post_title."</option>";
}


endif;

endif;?>
 ?>
</select>
</div>
<?php elseif (isset( $petro_config['footer-type'] ) && $petro_config['footer-type']=='option'): 

$pre_footer_pages  = isset($petro_config['pre-footer-pages']) ? $petro_config['pre-footer-pages'] : array();
$pre_footer_pages = array_map('absint',(array)$pre_footer_pages);

$pre_footer= isset($page_args['pre_page_footer']) ? absint($page_args['pre_page_footer']): '';

?>
<div id="page-footer">
<p><strong><?php esc_html_e('Pre Footer Option','petro') ?></strong></p>
<p><?php esc_html_e( 'The option pre footer must defined in theme option first.','petro'); ?></p>
<select name="pre_page_footer" id="page_footer">
<option value=''><?php esc_html_e('Default Pre Footer','petro'); ?></option>
<?php 

if(count($pre_footer_pages)):

$args = array(
      'post_type'    => 'page',
      'post_status' => 'publish',
      'posts_per_page' => -1,
      'include'=> $pre_footer_pages
);

$pages = get_pages( $args );

  if(count($pages)):

  foreach ( $pages as $page ) {

    echo "\n\t<option value='".$page->ID."' ".selected($page->ID,$pre_footer).">".$page->post_title."</option>";
  }


  endif;

endif;?>
 ?>
</select>
</div>
<?php endif;?>

<p><strong><?php esc_html_e('Order','petro'); ?></strong></p>
<p><label class="screen-reader-text" for="menu_order"><?php esc_html_e('Order','petro'); ?></label><input name="menu_order" type="text" size="4" id="menu_order" value="<?php echo esc_attr($post->menu_order); ?>" /></p>
<p><?php esc_html_e( 'Need help? Use the Help tab in the upper right of your screen.','petro'); ?></p>

<script type="text/javascript">
jQuery(document).ready(function($) {
  'use strict'; 

  var $select = $('select#page_template'), $sidebar_option = $('#custommeta'), $banner_options = $('#page-banner'),$page_footer = $('#page-footer');

  $select.live('change',function(){
    var this_value = $(this).val();

    switch ( this_value ) {
      case 'blank_page.php':
            $sidebar_option.fadeOut('slow');
            $banner_options.fadeOut('slow');
            if($page_footer.length) $page_footer.fadeOut('slow');
        break;
      case 'editor_page.php':
            $sidebar_option.fadeOut('slow');
            $banner_options.fadeIn('slow');
            if($page_footer.length) $page_footer.fadeIn('slow');
        break;
      default:
            $sidebar_option.fadeIn('slow');
            $banner_options.fadeIn('slow');
            if($page_footer.length) $page_footer.fadeIn('slow');
    }

  });

  $select.trigger('change');


    if ( ! $( '#banner_image_id' ).val() ) {
        $( '.remove_image_button' ).hide();
    }

    var file_frame;

    $( document ).on( 'click', '.upload_image_button', function( event ) {

        event.preventDefault();

        // If the media frame already exists, reopen it.
        if ( file_frame ) {
            file_frame.open();
            return;
        }

        // Create the media frame.
        file_frame = wp.media.frames.downloadable_file = wp.media({
            title: '<?php print esc_js( esc_html__( "Choose an image", "petro" )); ?>',
            button: {
                text: '<?php print esc_js( esc_html__( "Use image", "petro" )); ?>'
            },
            multiple: false
        });

        // When an image is selected, run a callback.
        file_frame.on( 'select', function() {
            var attachment = file_frame.state().get( 'selection' ).first().toJSON();

            $( '#banner_image_id' ).val( attachment.id );
            $( '#banner_image' ).find( 'img' ).attr( 'src', attachment.sizes.thumbnail.url );
            $( '.remove_image_button' ).show();
        });

        // Finally, open the modal.
        file_frame.open();
    });

    $('.remove_image_button').on( 'click', function(event){
      event.preventDefault();
      $( '#banner_image_id' ).val('');
      $( '#banner_image img').attr('src','<?php print plugin_dir_url(__FILE__)."/placeholder.png";?>');

    })



});
</script>
<?php  

  }

/*
 * Custom attributes
 * Since WP 5.0
 */

function get_custom_attributes_meta_box($post) {


  global $petro_config;

  wp_nonce_field( 'petro_attribute_metabox','petro_attribute_metabox');

  if ( 'page' != $post->post_type )
      return true;

  do_action('before_petro_attribute_metabox');

  wp_enqueue_media();

  $sidebar_position_options=array('default'=>esc_html__('Default','petro'),'left'=>esc_html__('Left','petro'),'right'=>esc_html__('Right','petro'),'nosidebar'=>esc_html__('No Sidebar','petro'));

  $page_args = get_post_meta( $post->ID, '_petro_page_args', true );

  $banner_image= isset($page_args['banner_id']) ? absint($page_args['banner_id']): '';
  $image_url=plugin_dir_url(__FILE__)."/placeholder.png";

  if($banner_image){
    $image = wp_get_attachment_image_src( $banner_image, array( 266,266 ));
    if($image)
      $image_url=$image[0];
  }

  $hide_title = isset($page_args['hide_title']) ? absint($page_args['hide_title']): '';
  $hide_title_heading = isset($page_args['hide_title_heading']) ? absint($page_args['hide_title_heading']): '';
  $sidebar_position = isset($page_args['sidebar_position']) ? $page_args['sidebar_position']: '';

  $menu_id= isset($page_args['menu_id']) ? absint($page_args['menu_id']): '';

   ?>
<p id="hide_banner_option">
  <input type="checkbox" name="hide_title" id="hide_title" value="1" <?php echo ($hide_title)?'checked="checked"':""?>/> <?php esc_html_e('Disable heading banner','petro') ?>
</p>
<p id="hide_title_option">
  <input type="checkbox" name="hide_title_heading" id="hide_title_heading" value="1" <?php echo ($hide_title_heading)?'checked="checked"':""?>/> <?php esc_html_e('Hide title heading','petro') ?>
</p>

<div id="custommeta">
<p id="sidebar_option">
  <strong><?php esc_html_e('Sidebar Position','petro') ?></strong>&nbsp;
<select name="sidebar_position" id="sidebar_position">
<?php foreach ($sidebar_position_options as $position=>$label) {
  print "<option value='".$position."'".(($sidebar_position == $position)?" selected":"").">".ucwords($label)."</option>";

}?>
</select>
</p>
</div>

<div id="page-menu">
<?php 

$menus = wp_get_nav_menus( array() );

?>
<p><strong><?php esc_html_e('Main Menu','petro_core_module'); ?></strong></p>
<p><?php esc_html_e( 'Select main menu if want individual menu for this page.','petro_core_module'); ?></p>
<select name="menu_id" id="menu_id">
<option value=''><?php esc_html_e('Default','petro_core_module'); ?></option>
<?php 

  if($menus && count($menus)):

  foreach ( $menus as $item  ) {

    echo "\n\t<option value='".$item->term_id."' ".selected($item->term_id, $menu_id, false ).">".$item->name."</option>";
  }

  endif;

?>
</select>
</div>

<div id="page-banner">
<p>
  <strong><?php esc_html_e('Heading Image','petro') ?></strong>
</p>
   <div id="banner_image"><img class="btn btn-link upload_image_button" src="<?php echo esc_url( $image_url ); ?>" width="200px" height="200px" /></div>
    <div style="line-height: 60px;">
        <input type="hidden" id="banner_image_id" name="banner_id" value="<?php print ($banner_image)? $banner_image:"";?>" />
        <button type="button" class="upload_image_button button"><?php esc_html_e( 'Upload/Change image', 'petro' ); ?></button>
        <button type="button" class="remove_image_button button"><?php esc_html_e( 'Remove image', 'petro' ); ?></button>
    </div>
</div>


<?php 
if(isset( $petro_config['footer-type'] ) && $petro_config['footer-type']=='page'):
$footer_pages  = isset($petro_config['footer-pages']) ? $petro_config['footer-pages'] : array();
$footer_pages = array_map('absint',(array)$footer_pages);

$page_footer= isset($page_args['page_footer']) ? absint($page_args['page_footer']): '';


?>
<div id="page-footer">
<p><strong><?php esc_html_e('Footer Option','petro') ?></strong></p>
<p><?php esc_html_e( 'The option footer must defined in theme option first.','petro'); ?></p>
<select name="page_footer" id="page_footer">
<option value=''><?php esc_html_e('Default Footer','petro'); ?></option>
<?php 

if(count($footer_pages)):

$args = array(
      'post_type'    => 'page',
      'post_status' => 'publish',
      'posts_per_page' => -1,
      'include'=> $footer_pages
);

$pages = get_pages( $args );

if(count($pages)):

foreach ( $pages as $page ) {

  echo "\n\t<option value='".$page->ID."' ".selected($page->ID,$page_footer).">".$page->post_title."</option>";
}


endif;

endif;?>
 ?>
</select>
</div>
<?php elseif (isset( $petro_config['footer-type'] ) && $petro_config['footer-type']=='option'): 

$pre_footer_pages  = isset($petro_config['pre-footer-pages']) ? $petro_config['pre-footer-pages'] : array();
$pre_footer_pages = array_map('absint',(array)$pre_footer_pages);

$pre_footer= isset($page_args['pre_page_footer']) ? absint($page_args['pre_page_footer']): '';

?>
<div id="page-footer">
<p><strong><?php esc_html_e('Pre Footer Option','petro') ?></strong></p>
<p><?php esc_html_e( 'The option pre footer must defined in theme option first.','petro'); ?></p>
<select name="pre_page_footer" id="page_footer">
<option value=''><?php esc_html_e('Default Pre Footer','petro'); ?></option>
<?php 

if(count($pre_footer_pages)):

$args = array(
      'post_type'    => 'page',
      'post_status' => 'publish',
      'posts_per_page' => -1,
      'include'=> $pre_footer_pages
);

$pages = get_pages( $args );

  if(count($pages)):

  foreach ( $pages as $page ) {

    echo "\n\t<option value='".$page->ID."' ".selected($page->ID,$pre_footer).">".$page->post_title."</option>";
  }


  endif;

endif;?>
 ?>
</select>
</div>
<?php endif;?>

<script type="text/javascript">
jQuery(document).ready(function($) {
  'use strict'; 

  var $select = $('.editor-page-attributes__template select.components-select-control__input,select#page_template'), $sidebar_option = $('#custommeta'), $banner_options = $('#page-banner'),$page_footer = $('#page-footer'), $page_menu = $('#page-menu');

  $select.live('change',function(){
    var this_value = $(this).val();

    switch ( this_value ) {
      case 'blank_page.php':
            $sidebar_option.fadeOut('slow');
            $banner_options.fadeOut('slow');
            if($page_footer.length) $page_footer.fadeOut('slow');
            if($page_menu.length) $page_menu.fadeOut('slow');
        break;
      case 'editor_page.php':
            $sidebar_option.fadeOut('slow');
            $banner_options.fadeIn('slow');
            if($page_footer.length) $page_footer.fadeIn('slow');
            if($page_menu.length) $page_menu.fadeIn('slow');
        break;
      default:
            $sidebar_option.fadeIn('slow');
            $banner_options.fadeIn('slow');
            if($page_footer.length) $page_footer.fadeIn('slow');
            if($page_menu.length) $page_menu.fadeIn('slow');
    }

  });

  $select.trigger('change');


    if ( ! $( '#banner_image_id' ).val() ) {
        $( '.remove_image_button' ).hide();
    }

    var file_frame;

    $( document ).on( 'click', '.upload_image_button', function( event ) {

        event.preventDefault();

        // If the media frame already exists, reopen it.
        if ( file_frame ) {
            file_frame.open();
            return;
        }

        // Create the media frame.
        file_frame = wp.media.frames.downloadable_file = wp.media({
            title: '<?php print esc_js( esc_html__( "Choose an image", "petro" )); ?>',
            button: {
                text: '<?php print esc_js( esc_html__( "Use image", "petro" )); ?>'
            },
            multiple: false
        });

        // When an image is selected, run a callback.
        file_frame.on( 'select', function() {
            var attachment = file_frame.state().get( 'selection' ).first().toJSON();

            $( '#banner_image_id' ).val( attachment.id );
            $( '#banner_image' ).find( 'img' ).attr( 'src', attachment.sizes.thumbnail.url );
            $( '.remove_image_button' ).show();
        });

        // Finally, open the modal.
        file_frame.open();
    });

    $('.remove_image_button').on( 'click', function(event){
      event.preventDefault();
      $( '#banner_image_id' ).val('');
      $( '#banner_image img').attr('src','<?php print plugin_dir_url(__FILE__)."/placeholder.png";?>');

    })



});
</script>
<?php  
  
  do_action('after_petro_attribute_metabox');

  }

  function deactive_notice(){

    echo "<div class='error'>" .  esc_html__( 'Petro Theme Core used for Petro Theme, please activate the theme first.' ,'petro_core_module'). "</div>";

  }

  function deactive(){

    deactivate_plugins( array(plugin_basename(__FILE__)), true, is_network_admin() );
  }

}



function petro_valid_page_attributes(){

  $valid_attrs = array(
      'sidebar_position',
      'banner_id',
      'menu_id',
      'hide_title',
      'page_footer',
      'pre_page_footer',
      'hide_title_heading'
  );

  return apply_filters( 'petro_valid_page_attributes', $valid_attrs);
}

$attributes = new petro_page_attributes()
?>